@@ -1,13 +1,13 @@
 function definput=arg_firwin(definput)
-  
-  definput.flags.wintype={ 'hanning','hann','sine','cosine', ...
-                      'sqrthann','hamming', 'square','rect', ...
-                      'tria','bartlett', ...
-                      'triangular','sqrttria','blackman','blackman2', ...
-                      'nuttall','nuttall10','nuttall01','nuttall20', ...
-                      'nuttall11','nuttall03', 'nuttall12','nuttall21', ...
-                      'nuttall30', 'ogg','itersine'};
-  
+ 
+truncgaussflags = {'truncgauss'};
+
+definput.flags.wintype=[{...
+    'hanning','hann','sine','cosine', 'sqrthann','hamming', 'square',...
+    'rect', 'tria','bartlett', 'triangular','sqrttria','blackman',...
+    'blackman2', 'nuttall','nuttall10','nuttall01','nuttall20',...
+    'nuttall11','nuttall03', 'nuttall12','nuttall21', 'nuttall30',...
+    'ogg', 'itersine', 'nuttall02'}, truncgaussflags ];
 
 
 %-*- texinfo -*-
@@ -17,8 +17,8 @@ function definput=arg_firwin(definput)
 %@strong{Url}: @url{http://ltfat.github.io/doc/comp/arg_firwin.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.1.1
+% Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.2.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
