@@ -14,8 +14,8 @@ function [g,info] = comp_fourierwindow(g,L,callfun);
 %@seealso{gabwin, wilwin}
 %@end deftypefn
 
-% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.1.1
+% Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.2.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -115,11 +115,9 @@ end
                 g.h = g.h(:);
             end
             
-            % In case a filter lacks .offset, treat it as if it was
-            % a zero delay FIR window.
+            % In case a filter lacks .offset, set it to zero
             if ~isfield(g,'offset')
-                g.h=fftshift(g.h);
-                g.offset=-floor(info.gl/2); 
+                g.offset= 0; 
             end
         elseif isfield(g,'H')  && ... 
                ( isnumeric(g.H) && isvector(g.H) || isa(g.H,'function_handle') )
