@@ -18,8 +18,8 @@ function [g,info] = comp_window(g,a,M,L,lt,callfun);
 %@seealso{gabwin, wilwin}
 %@end deftypefn
 
-% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.1.1
+% Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.2.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -158,6 +158,9 @@ if isnumeric(g)
       info.wasrow=1;
     end;
   end;
+  if isempty(L)
+      info.isfir = 1; 
+  end
 end;
 
 if rem(length(g),M)~=0
@@ -184,9 +187,9 @@ function complain_L(L,callfun)
 function isfir=test_isfir(gorig,M)
     % Original window is FIR, dual window is FIR if length of the original
     % window is <= M. This is true if the length was not explicitly
-    % defined (gorig{2}).
+    % defined (gorig{2}) or gorig was given as a numeric vector explicitly.
       if iscell(gorig) && numel(gorig)>1 && isnumeric(gorig{2}) && gorig{2}<=M...
-         || ischar(gorig)   
+         || ischar(gorig) || isnumeric(gorig) && numel(gorig)<=M   
         isfir = 1; 
       else
          isfir = 0;
