@@ -5,7 +5,7 @@ if nargin<2
 end
 
 if ~isstruct(F) || ~isfield(F,'frana')
-  error('%s: Agument F must be a frame definition structure.',...
+  error('%s: Argument F must be a frame definition structure.',...
         upper(callfun));
 end;
 
@@ -17,8 +17,8 @@ end;
 %@strong{Url}: @url{http://ltfat.github.io/doc/comp/complainif_notvalidframeobj.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.1.1
+% Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.2.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
