@@ -31,8 +31,8 @@ function demo_blockproc_effects(source,varargin)
 %@strong{Url}: @url{http://ltfat.github.io/doc/demos/demo_blockproc_effects.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.1.1
+% Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.2.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -64,15 +64,19 @@ Fmorph = blockframeaccel(Fmorph, bufLen,'segola');
 
 haveWav = 0;
 try
-   ff = 0.4*wavread('beat.wav');
+   [ff, fsbeat] = wavload('beat.wav'); ff = ff(:,1);
    %ff = 0.8*resample(ff,4,1);
-   ffblocks = reshape(postpad(ff,ceil(numel(ff)/bufLen)*bufLen),bufLen,[]);
+   ffblocks = reshape(postpad(ff,ceil(size(ff,1)/bufLen)*bufLen),bufLen,[]);
    cidx = 1;
    haveWav = 1;
 catch
    warning('beat.wav not found. morphing effect is disabled.');
 end
 
+if haveWav && fsbeat~=44100
+    error('%s: beat.wav must be sampled at 44.1 kHz.',upper(mfilename));
+end
+
 % Plain analysis params
 Fana = frame('dgtreal',{'hann',882},300,3000);
 Fana = blockframeaccel(Fana, bufLen,'segola');
