@@ -17,8 +17,8 @@ function test_failed=test_gabmulappr
 %@strong{Url}: @url{http://ltfat.github.io/doc/testing/test_gabmulappr.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.1.1
+% Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.2.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -66,8 +66,8 @@ for ii=1:length(Lr);
   disp(s)
   
   % ---- Reconstruction test, tight Gaussian window ------------
-     
-  Tr=tfmat('gabmul',sym,a);
+  Tr = gabmulmatrix(frame('dgt',gabtight(a,M,L),a,M),sym);   
+  %Tr=tfmat('gabmul',sym,a);
   symnew=gabmulappr(Tr,a,M);
   
   res=norm(sym-symnew,'fro');
@@ -95,8 +95,8 @@ for ii=1:length(Lr);
   disp(s)
 
   % ---- Reconstruction test, same window for analysis and synthesis ------------
-     
-  Tr=tfmat('gabmul',sym,g,a);
+  Tr = gabmulmatrix(frame('dgt',g,a,M),sym);
+  %Tr=tfmat('gabmul',sym,g,a);
   symnew=gabmulappr(Tr,g,a,M);
   
   res=norm(sym-symnew,'fro');
@@ -118,8 +118,8 @@ for ii=1:length(Lr);
   disp(s) 
 
   % ---- Reconstruction test, two different windows for analysis and synthesis ---------
-     
-  Tr=tfmat('gabmul',sym,ga,gs,a);
+  Tr = gabmulmatrix2(frame('dgt',ga,a,M),frame('dgt',gs,a,M),sym);     
+  %Tr=tfmat('gabmul',sym,ga,gs,a);
   symnew=gabmulappr(Tr,ga,gs,a,M);
   
   res=norm(sym-symnew,'fro');
@@ -132,5 +132,11 @@ for ii=1:length(Lr);
 end;
 
 
+function T = gabmulmatrix(F,sym)
 
+T = operatormatrix(operatornew('framemul',F,F,framenative2coef(F,sym)));
+
+function T = gabmulmatrix2(Fa,Fs,sym)
+
+T = operatormatrix(operatornew('framemul',Fa,Fs,framenative2coef(Fs,sym)));
 
