@@ -23,7 +23,7 @@ tests_todo={
     'fwt','blockfwt','ufwt','wfbt','uwfbt','wpfbt','uwpfbt','fwt2','undeceq',...
     'wfbt2filterbank','freqorder','gga','chirpzt',...
     'frames', 'frametf', 'frft', 'nonu2ufilterbank', 'dtwfb', 'dtwfb2filterbank',...
-    'ambiguityfunction','wignervilledist'
+    'ambiguityfunction','wignervilledist','constructphase'
            };
 
 if ~isempty(kv.tests)
@@ -87,8 +87,8 @@ end
 %@strong{Url}: @url{http://ltfat.github.io/doc/testing/test_all_ltfat.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.1.1
+% Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.2.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
