@@ -47,7 +47,7 @@ octave_value_list octFunction(const octave_value_list& args, int nargout)
     // Number of channels
     const octave_idx_type W  = F.columns();
     // Number of filters
-    const octave_idx_type M = G.nelem();
+    const octave_idx_type M = G.numel();
 
     // Allocating temporary arrays
     // Output subband lengths
