@@ -50,7 +50,7 @@ octave_value_list octFunction(const octave_value_list& args, int nargout)
     // Number of channels
     const octave_idx_type W  = c.elem(0).columns();
     // Number of filters
-    const octave_idx_type M = G.nelem();
+    const octave_idx_type M = G.numel();
 
     // Output signal
     MArray<LTFAT_COMPLEX> F(dim_vector(L, W));
