@@ -52,7 +52,7 @@ octave_value_list octFunction(const octave_value_list& args, int nargout)
     // Number of channels
     const octave_idx_type W  = c.elem(0).columns();
     // Number of filters
-    const octave_idx_type M = G.nelem();
+    const octave_idx_type M = G.numel();
 
     OCTAVE_LOCAL_BUFFER (double, afrac, M);
     memcpy(afrac,a,M*sizeof(double));
@@ -86,7 +86,7 @@ octave_value_list octFunction(const octave_value_list& args, int nargout)
         GPtrs[m] = GElems[m].data();
         cElems[m] = ltfatOctArray<LTFAT_COMPLEX>(c.elem(m));
         cPtrs[m] = cElems[m].data();
-        Gl[m] = GElems[m].nelem();
+        Gl[m] = GElems[m].numel();
     }
 
     // Output length
