@@ -74,7 +74,7 @@ octave_value_list octFunction(const octave_value_list& args, int nargout)
     const octave_idx_type ptype = args(5).int_value();
     const octave_idx_type N = L / a;
     const octave_idx_type M2 = M / 2 + 1;
-    const octave_idx_type W = coef.nelem() / (N * M2);
+    const octave_idx_type W = coef.numel() / (N * M2);
     const octave_idx_type gl = gf.rows();
 
     MArray<LTFAT_REAL> f(dim_vector(L, W));
